[med-svn] [python-mne] 315/376: TEST: test find EOG peaks

Yaroslav Halchenko debian at onerussian.com
Fri Nov 27 17:23:14 UTC 2015


This is an automated email from the git hooks/post-receive script.

yoh pushed a commit to annotated tag v0.1
in repository python-mne.

commit 6ddb6fa9f154670bdc9693bb079345cbe7b43cb5
Author: Alexandre Gramfort <alexandre.gramfort at inria.fr>
Date:   Thu Jul 7 12:03:53 2011 +0200

    TEST: test find EOG peaks
---
 mne/artifacts/tests/test_ecg.py                  |  1 +
 mne/artifacts/tests/{test_ecg.py => test_eog.py} | 15 ++++++---------
 2 files changed, 7 insertions(+), 9 deletions(-)

diff --git a/mne/artifacts/tests/test_ecg.py b/mne/artifacts/tests/test_ecg.py
index 66d8cb0..e7da1c2 100644
--- a/mne/artifacts/tests/test_ecg.py
+++ b/mne/artifacts/tests/test_ecg.py
@@ -10,6 +10,7 @@ raw_fname = op.join(data_path, 'test_raw.fif')
 event_fname = op.join(data_path, 'test-eve.fif')
 proj_fname = op.join(data_path, 'test_proj.fif')
 
+
 def test_find_ecg():
     """Test find ECG peaks"""
     raw = Raw(raw_fname)
diff --git a/mne/artifacts/tests/test_ecg.py b/mne/artifacts/tests/test_eog.py
similarity index 51%
copy from mne/artifacts/tests/test_ecg.py
copy to mne/artifacts/tests/test_eog.py
index 66d8cb0..865e8fd 100644
--- a/mne/artifacts/tests/test_ecg.py
+++ b/mne/artifacts/tests/test_eog.py
@@ -1,20 +1,17 @@
 import os.path as op
 
-from numpy.testing import assert_array_almost_equal
-
 from ...fiff import Raw
-from ..ecg import find_ecg_events
+from ..eog import find_eog_events
 
 data_path = op.join(op.dirname(__file__), '..', '..', 'fiff', 'tests', 'data')
 raw_fname = op.join(data_path, 'test_raw.fif')
 event_fname = op.join(data_path, 'test-eve.fif')
 proj_fname = op.join(data_path, 'test_proj.fif')
 
-def test_find_ecg():
-    """Test find ECG peaks"""
+
+def test_find_eog():
+    """Test find EOG peaks"""
     raw = Raw(raw_fname)
-    events = find_ecg_events(raw, event_id=999)
+    events = find_eog_events(raw)
     n_events = len(events)
-    _, times = raw[0, :]
-    average_pulse = 60.0 * (times[-1] - times[0]) / n_events
-    assert 60 < average_pulse < 65
+    assert n_events == 4

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/debian-med/python-mne.git



More information about the debian-med-commit mailing list